<?php
/**
 * Do not load this file directly
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * WPJ_OpenGraph_Admin class.
 *
 * @since 0.1.0
 */
class WPJ_OpenGraph_Admin {

	/**
	 * If no instance of WPJ_OpenGraph_Admin has been made then let's make it.
	 *
	 * @var object $instance
	 * @access private
	 * @static
	 *
	 * @since 0.1.0
	 */
	private static $instance = null;

	/**
	 * Kick off the class if it hasn't been instantiated.
	 *
	 * @return Singleton The Singleton instance of this class.
	 * @access public
	 * @static
	 *
	 * @since 0.1.0
	 */
	public static function get_instance() {
		if ( ! self::$instance ) {
			self::$instance = new WPJ_OpenGraph_Admin;
		}
		return self::$instance;
	}

	/**
	 * Init function.
	 *
	 * @since 0.1.0
	 */
	public function init() {
		add_action( 'cmb2_admin_init', array( $this, 'register_opengraph_settings' ) );
	}

    /**
     * Registers a new settings page under Settings menu.
	 *
	 * @since 0.1.0
     */
	public function register_opengraph_settings() {
		/**
		 * Registers settings page menu item and form.
		 */
		$wpj_settings = new_cmb2_box( array(
			'id'           => 'wpj_opengraph_settings',
			'title'        => esc_html__( 'OpenGraph Settings' ),
			'object_types' => array( 'options-page' ),
			'option_key'   => 'wpj-opengraph-settings',
			'parent_slug'  => 'options-general.php',
			'capability'   => 'manage_options',
			'save_button'  => esc_html__( 'Save Settings' ),
		) );

		/**
		 * Register fields.
		 */
		$wpj_settings->add_field( array(
			'name' => __( 'Facebook App ID' ),
			'id'   => 'wpj_fb_appid',
			'type' => 'text',
			'default' => '',
		) );

		$wpj_settings->add_field( array(
			'name'    => 'Image URL',
			'desc'    => 'This image is used if the post/page being shared does not contain any images.',
			'id'      => 'wpj_ogp_image',
			'type'    => 'file',
			'text'    => array(
				'add_upload_file_text' => 'Upload'
			),
			'query_args' => array(
				'type' => array(
				'image/jpeg',
				'image/png',
				),
			),
			'preview_size' => 'large',
		) );
	}

}